@@ -3,7 +3,6 @@ import typing
 import starlette.applications
 import starlette.background
 import starlette.datastructures
-import starlette.exceptions
 import starlette.requests
 import starlette.responses
 import starlette.routing
@@ -58,7 +57,7 @@ class _OperationApp:
             starlette.types.Receive: receive,
             starlette.types.Send: send,
         }
-        xpresso_scope: asgi_scope_extension.xpressoASGIExtension = scope["extensions"][
+        xpresso_scope: asgi_scope_extension.XpressoASGIExtension = scope["extensions"][
             "xpresso"
         ]
         async with xpresso_scope["container"].enter_scope("operation") as container:
@@ -72,7 +71,7 @@ class _OperationApp:
             else:
                 response = self.response_factory(self.response_encoder(endpoint_return))
             xpresso_scope["response"] = response
-        await xpresso_scope["response"](scope, receive, send)
+        await response(scope, receive, send)
 
 
 class Operation(starlette.routing.BaseRoute):
@@ -140,7 +139,9 @@ class Operation(starlette.routing.BaseRoute):
     ) -> None:
         self.dependant = container.solve(
             JoinedDependant(
-                Dependant(self.endpoint, sync_to_thread=self.sync_to_thread),
+                Dependant(
+                    self.endpoint, scope="operation", sync_to_thread=self.sync_to_thread
+                ),
                 siblings=[*dependencies, *(self.dependencies or ())],
             )
         )
